@@ -1,9 +1,6 @@
 ##### BreastCancer -----
 #' Wisconsin Breast Cancer Database
 #'
-#' Formatted subset of `mlbench's` `BreastCancer` (not explicitly exported). 
-#' See `help(BreastCancer, package = "mlbench")` for the original documentation.
-#' 
 #' The objective is to identify each of a number of benign or malignant classes.
 #' Samples arrive periodically as Dr. Wolberg reports his clinical cases. The 
 #' database therefore reflects this chronological grouping of the data. This 
@@ -12,8 +9,11 @@
 #' primitive numerical attributes with values ranging from 0 through 10. Rows
 #' with missing attribute values and duplicate rows removed.
 #'
-#' Data frame with 675 observations of 11 variables: factor Id, 
-#' 9 numeric variables, and target factor Class.
+#' This is a cleaned subset of `mlbench`'s `BreastCancer`.
+#' See `help(BreastCancer, package = "mlbench")` for the original.
+#'
+#' @format A data frame with 675 observations of 8 numeric variables and 
+#' target factor `Class`.
 #' \itemize{
 #'   \item Id, Sample code number
 #'   \item Cl.thickness, Clump thickness
@@ -28,43 +28,43 @@
 #'   \item Class, Class of cancer, either "benign" or "malignant"
 #' }
 #' @details 
-#' Reproducing this dataset:
+#' Replicating this dataset:
 #' ```
 #' require("mlbench")
 #' data(BreastCancer)
 #' 
-#' d <- BreastCancer
-#' d <- d[!duplicated(d), ] ## Remove 8 duplicate rows
-#' d <- d[complete.cases(d), ] ## Remove 16 row-wise incomplete rows
-#' mat <- as.matrix(d[ , 2:10])
-#' mat <- sapply(mat, as.integer)
-#' BreastCancer <- 
-#'   data.frame(Id = as.factor(d$Id), mat, Class = as.factor(d$Class))
+#' raw <- BreastCancer
+#' ## rownumber index of 8 duplicate 16 incomplete rows
+#' idx <- !duplicated(raw) & complete.cases(raw) 
+#' d <- raw[idx, 3:10]
+#' d <- apply(d, 2L, as.integer)
+#' d <- data.frame(d, Class = as.factor(raw$Class[idx]))
+#' BreastCancer <- d
 #' ## save(BreastCancer, file = "./data/BreastCancer.rda")
 #' ```
 #' @name BreastCancer
 #' @docType data
-#' @format Data frame with 675 observations of 11 variables: factor Id, 
-#' 9 integer variables, and target factor Class.
+#' @source {J.W. Smith., el al. 1988. Using the ADAP learning algorithm to forecast the onset of diabetes mellitus. In Proceedings of the Symposium on Computer Applications and Medical Care (pp. 261--265). IEEE Computer Society Press.}
+#' @source {mlbench, R package. F. Leisch & E. Dimitriadou, 2021. mlbench: Machine Learning Benchmark Problems} \url{https://CRAN.R-project.org/package=mlbench}
 #' @examples
-#' str(BreastCancer)
-#' \dontrun{
-#' dat <- scale_sd(BreastCancer[, 2:10])
-#' clas <- BreastCancer$Class
-#' bas <- prcomp(dat)$rotation[, 1:2]
-#' mvar <- which(abs(bas[, 1]) == max(abs(bas[, 1])))
+#' library("spinifex")
+#' str(spinifex::BreastCancer)
+#' dat <- scale_sd(spinifex::BreastCancer[, 1:8])
+#' clas <- spinifex::BreastCancer$Class
 #' 
-#' play_manual_tour(basis = bas, data = dat, manip_var = mvar,
-#'                  render_type = render_gganimate, color = clas, shape = clas)
-#' }
+#' bas <- basis_pca(dat)
+#' mv <- manip_var_of(bas)
+#' mt <- manual_tour(bas, mv)
+#' 
+#' ggt <- ggtour(mt, dat, angle = .2) +
+#'   proto_default(list(color = clas, shape = clas))
+#' \dontrun{
+#' animate_plotly(ggt)}
 "BreastCancer"
 
 ##### PimaIndiansDiabetes_wide -----
-#' Pima Indians Diabetes Database
+#' Pima Indians Diabetes Dataset, wide
 #'
-#' Formatted subset of `mlbench's` `PimaIndiansDiabetes2` (not explicitly exported). 
-#' See `help(PimaIndiansDiabetes2, package = "mlbench")` for the original documentation.
-#' 
 #' The data set PimaIndiansDiabetes2 contains a corrected version of the 
 #' original data set. While the UCI repository index claims that there are no 
 #' missing values, closer inspection of the data shows several physical 
@@ -72,8 +72,11 @@
 #' PimaIndiansDiabetes2, all zero values of glucose, pressure, triceps, insulin 
 #' and mass have been set to NA, see also Wahba et al (1995) and Ripley (1996).
 #'
-#' Data frame with 392 observations of 9 variables:
-#' 8 numeric variables, and target factor diabetes.
+#' This is a cleaned subset of `mlbench`'s `PimaIndiansDiabetes2`.
+#' See `help(PimaIndiansDiabetes2, package = "mlbench")`.
+#'
+#' @format A data frame with 392 observations of 
+#' 8 numeric variables, and target factor `diabetes`.
 #' \itemize{
 #'   \item pregnant, Number of times pregnant
 #'   \item glucose, Plasma glucose concentration (glucose tolerance test)
@@ -86,7 +89,7 @@
 #'   \item diabetes, Class variable (test for diabetes), either "pos" or "neg"
 #' }
 #' @details 
-#' Reproducing this dataset:
+#' Replicating this dataset:
 #' ```
 #' require("mlbench")
 #' data(PimaIndiansDiabetes2)
@@ -98,26 +101,25 @@
 #' ```
 #' @name PimaIndiansDiabetes_wide
 #' @docType data
-#' @format Data frame with 392 observations of 9 variables:
-#' 8 numeric variables, and target factor diabetes.
+
 #' @examples
+#' library("spinifex")
 #' str(PimaIndiansDiabetes_wide)
-#' \dontrun{
 #' dat <- scale_sd(PimaIndiansDiabetes_wide[, 1:8])
 #' clas <- PimaIndiansDiabetes_wide$diabetes
-#' bas <- prcomp(dat)$rotation[, 1:2]
-#' mvar <- which(abs(bas[, 1]) == max(abs(bas[, 1])))
 #' 
-#' play_manual_tour(basis = bas, data = dat, manip_var = mvar),
-#'                  render_type = render_gganimate, color = clas, shape = clas)
-#' }
+#' bas <- basis_pca(dat)
+#' mv <- manip_var_of(bas)
+#' mt <- manual_tour(bas, mv)
+#' 
+#' ggt <- ggtour(mt, dat, angle = .2) +
+#'   proto_default(list(color = clas, shape = clas))
+#' \dontrun{
+#' animate_plotly(ggt)}
 "PimaIndiansDiabetes_wide"
 
 ##### PimaIndiansDiabetes_long -----
-#' Pima Indians Diabetes Database
-#'
-#' Formatted subset of `mlbench's` `PimaIndiansDiabetes2` (not explicitly exported). 
-#' See `help(PimaIndiansDiabetes2, package = "mlbench")` for the original documentation.
+#' Pima Indians Diabetes Dataset, long
 #' 
 #' The data set PimaIndiansDiabetes2 contains a corrected version of the 
 #' original data set. While the UCI repository index claims that there are no 
@@ -126,8 +128,11 @@
 #' PimaIndiansDiabetes2, all zero values of glucose, pressure, triceps, insulin 
 #' and mass have been set to NA, see also Wahba et al (1995) and Ripley (1996).
 #'
-#' Data frame with 724 observations of 7 variables:
-#' 6 numeric variables, and target factor diabetes.
+#' This is a cleaned subset of `mlbench's` `PimaIndiansDiabetes2`. 
+#' See `help(PimaIndiansDiabetes2, package = "mlbench")`.
+#'
+#' @format A data frame with 724 observations of
+#' 6 numeric variables, and target factor `diabetes`.
 #' \itemize{
 #'   \item pregnant, Number of times pregnant
 #'   \item glucose, Plasma glucose concentration (glucose tolerance test)
@@ -137,8 +142,8 @@
 #'   \item age, Age (years)
 #'   \item diabetes, Class variable (test for diabetes), either "pos" or "neg"
 #' }
-#' @details 
-#' Reproducing this dataset:
+#' @details
+#' Replicating this dataset:
 #' ```
 #' require("mlbench")
 #' data(PimaIndiansDiabetes2)
@@ -151,26 +156,27 @@
 #' ```
 #' @name PimaIndiansDiabetes_long
 #' @docType data
-#' @format Data frame with 724 observations of 7 variables:
-#' 6 numeric variables, and target factor diabetes.
+#' @source {J.W. Smith., el al. 1988. Using the ADAP learning algorithm to forecast the onset of diabetes mellitus. In Proceedings of the Symposium on Computer Applications and Medical Care (pp. 261--265). IEEE Computer Society Press.}
+#' @source {mlbench, R package. F. Leisch & E. Dimitriadou, 2021. mlbench: Machine Learning Benchmark Problems} \url{https://CRAN.R-project.org/package=mlbench}
 #' @examples
+#' library("spinifex")
 #' str(PimaIndiansDiabetes_long)
-#' \dontrun{
 #' dat <- scale_sd(PimaIndiansDiabetes_long[, 1:6])
 #' clas <- PimaIndiansDiabetes_long$diabetes
-#' bas <- prcomp(dat)$rotation[, 1:2]
-#' mvar <- which(abs(bas[, 1]) == max(abs(bas[, 1])))
 #' 
-#' play_manual_tour(basis = bas, data = dat, manip_var = mvar,
-#'                  render_type = render_gganimate, color = clas, shape = clas)
-#' }
+#' bas <- basis_pca(dat)
+#' mv <- manip_var_of(bas)
+#' mt <- manual_tour(bas, mv)
+#' 
+#' ggt <- ggtour(mt, dat, angle = .2) +
+#'   proto_default(list(color = clas, shape = clas))
+#' \dontrun{
+#' animate_plotly(ggt)}
 "PimaIndiansDiabetes_long"
 
 ##### weather -----
 #' Sample dataset of daily weather observations from Canberra airport in Australia.
 #' 
-#' A subset from `rattle.data::weather`, instructions to reproduce below.
-#' 
 #' One year of daily weather observations collected from the Canberra airport 
 #' in Australia was obtained from the Australian Commonwealth Bureau of 
 #' Meteorology and processed to create this sample dataset for illustrating 
@@ -181,22 +187,18 @@
 #' `RISK_MM` (how much rain recorded in millimeters). Various transformations 
 #' were performed on the source data. The dataset is quite small and is useful 
 #' only for repeatable demonstration of various data science operations.
-#' 
-#' The source dataset is Copyright by the Australian Commonwealth Bureau of 
-#' Meteorology and is provided as part of the rattle package with permission.
 #'
-#' Data frame of 366 observations of 20 variables. One year of 
+#' This is a cleaned subset of `rattle::weather`.
+#'
+#' @format A data frame of 354 observations of 20 variables. One year of 
 #' daily observations of weather variables at Canberra airport in Australia 
-#' starting November 2007:
+#' between November 1, 2007 and October 31, 2008.
 #' \itemize{
 #'   \item Date, The date of observation (Date class).
 #'   \item MinTemp, The minimum temperature in degrees Celsius.
 #'   \item MaxTemp, The maximum temperature in degrees Celsius.
 #'   \item Rainfall, The amount of rainfall recorded for the day in mm.
 #'   \item Evaporation, The "Class A pan evaporation" (mm) in the 24 hours to 9am.
-#'   \item Sunshine, The number of hours of bright sunshine in the day.
-#'   \item WindGustSpeed, The speed (km/h) of the strongest wind gust in the 24 hours to midnight.
-#'   \item WindSpeed9am, Wind speed (km/hr) averaged over 10 minutes prior to 9am.
 #'   \item WindSpeed3pm, Wind speed (km/hr) averaged over 10 minutes prior to 3pm.
 #'   \item Humid9am, Relative humidity (percent) at 9am.
 #'   \item Humid3pm, Relative humidity (percent) at 3pm.
@@ -210,36 +212,37 @@
 #'   \item RainToday, Factor: "yes" if precipitation (mm) in the 24 hours to 9am exceeds 1mm, otherwise 0.
 #'   \item RainTomorrow, Factor: "yes" if it rained the following day, the target variable.
 #' }
+#' Copyright Commonwealth of Australia 2010,
+#' Bureau of Meteorology.
+#' Definitions adapted from http://www.bom.gov.au/climate/dwo/IDCJDW0000.shtml
 #' @details 
-#' Reproducing this dataset:
+#' Replicating this dataset:
 #' ```
-#' require("rattle.data")
-#' weather <- weather[, c(1, 3:7, 9, 12:21, 23, 22, 24)]
+#' require("rattle")
+#' d <- rattle::weather[, c(1, 3:7, 9, 12:21, 23, 22, 24)]
+#' d <- d[complete.cases(d), ] ## Remove ~12 row-wise incomplete rows
+#' d <- as.data.frame(d)  ## Remove tibble dependency
+#' weather <- d
 #' ## save(weather, file = "./data/weather.rda")
 #' ```
 #' @name weather
 #' @docType data
-#' @format Data frame of 366 observations of 20 variables. One year of 
-#' daily observations of weather variables at Canberra airport in Australia 
-#' between November 1, 2007 and October 31, 2008.
-#' @source The daily observations are available from http://www.bom.gov.au/climate/data. 
-#' Copyright Commonwealth of Australia 2010,
-#' Bureau of Meteorology.
-#'
-#' Definitions adapted from http://www.bom.gov.au/climate/dwo/IDCJDW0000.shtml
-#' @references Data source: http://www.bom.gov.au/climate/dwo/ and http://www.bom.gov.au/climate/data.
+#' @source {Bureau of Meteorology, Commonwealth of Australia} \url{http://www.bom.gov.au/climate/data/}
+#' @source {rattle, R package. G. Williams, 2020. rattle: Graphical User Interface for Data Science in R} \url{https://CRAN.R-project.org/package=rattle}
 #' @examples
-#' str(weather)
-#' \dontrun{
-#' dat <- scale_sd(weather[, 2:18])
-#' clas_x <- weather$RainToday
-#' clas_y <- weather$RainTomorrow
-#' bas <- prcomp(dat)$rotation[, 1:2]
-#' mvar <- which(abs(bas[, 1]) == max(abs(bas[, 1])))
+#' library("spinifex")
+#' str(spinifex::weather)
+#' dat <- scale_sd(spinifex::weather[, 2:18])
+#' clas <- spinifex::weather$RainTomorrow
 #' 
-#' play_manual_tour(basis = bas, data = dat, manip_var = mvar,
-#'                  render_type = render_gganimate, color = clas_y, shape = clas_x)
-#' }
+#' bas <- basis_pca(dat)
+#' mv <- manip_var_of(bas)
+#' mt <- manual_tour(bas, mv)
+#' 
+#' ggt <- ggtour(mt, dat, angle = .2) +
+#'   proto_default(list(color = clas, shape = clas))
+#' \dontrun{
+#' animate_plotly(ggt)}
 "weather"
 
 ##### wine -----
@@ -253,7 +256,7 @@
 #' The data contains no missing values and consist of only numeric data, with a 
 #' three class target variable (Type) for classification.
 #'
-#' Data frame of 178 observations of 13 variables, target 
+#' @format A data frame of 178 observations of target 
 #' class `Type` and 12 numeric variables:
 #' \itemize{
 #'   \item Type, The type of wine, the target factor, 1 (59 obs), 
@@ -272,25 +275,79 @@
 #'   \item Dilution, D280/OD315 of diluted wines
 #'   \item Proline, Proline
 #' }
-#' @details 
-#' Reproducing this dataset:
+#' @source {rattle, R package. G. Williams, 2020. rattle: Graphical User Interface for Data Science in R} \url{https://CRAN.R-project.org/package=rattle}
+#' @source {PARVUS. M. Forina. et al. 1988. Elsevier, Amsterdam, PARVUS: An extendable package of programs for data exploration, classification and correlation. ISBN 0-44-430121z}
+#' @details
+#' Replicating this dataset:
 #' ```
-#' requireNamespace("rattle.data")
-#' wine
+#' require("rattle")
+#' str(rattle::wine)
+#' ## save(wine, file = "./data/wine.rda")
 #' ```
 #' @name wine
 #' @docType data
-#' @format Data frame of 178 observations of 13 variables, target 
-#' class `Type` and 12 numeric variables.
 #' @examples
+#' library("spinifex")
 #' str(wine)
-#' \dontrun{
-#' dat <- scale_sd(wine[, 2:14])
+#' dat <- scale_sd(wine[, 2:6])
 #' clas <- wine$Type
-#' bas <- prcomp(dat)$rotation[, 1:2]
-#' mvar <- which(abs(bas[, 1]) == max(abs(bas[, 1])))
 #' 
-#' play_manual_tour(basis = bas, data = dat, manip_var = mvar,
-#'                  render_type = render_gganimate, color = clas, shape = clas)
+#' bas <- basis_pca(dat)
+#' mv <- manip_var_of(bas)
+#' mt <- manual_tour(bas, mv)
+#' 
+#' ggt <- ggtour(mt, dat, angle = .2) +
+#'   proto_default(list(color = clas, shape = clas))
+#' \dontrun{
+#' animate_plotly(ggt)}
+"wine"
+
+##### penguins -----
+#' Size measurements for adult foraging penguins near Palmer Station, Antarctica
+#' 
+#' Includes measurements for penguin species, island in Palmer Archipelago,
+#' size (flipper length, body mass, bill dimensions), and sex.
+#' 
+#' This is a cleaned subset of `palmerpenguins::penguins`.
+#'
+#' @format A data frame with 333 rows and 4 numeric variables and 3 factor variables
+#' \describe{
+#'   \item{bill_length_mm}{a number denoting bill length (millimeters)}
+#'   \item{bill_depth_mm}{a number denoting bill depth (millimeters)}
+#'   \item{flipper_length_mm}{an integer denoting flipper length (millimeters)}
+#'   \item{body_mass_g}{an integer denoting body mass (grams)}
+#'   \item{species}{a factor denoting penguin species (Adelie, Chinstrap and Gentoo)}
+#'   \item{sex}{a factor denoting penguin sex (female, male)}
+#'   \item{island}{a factor denoting island in Palmer Archipelago, Antarctica (Biscoe, Dream or Torgersen)}
 #' }
-"wine"
\ No newline at end of file
+#' @source {palmerpenguins R package. A. Horst, 2020. Palmer Archipelago (Antarctica) Penguin Data.} \url{https://CRAN.R-project.org/package=palmerpenguins}
+#' @source {Adelie penguins: Palmer Station Antarctica LTER and K. Gorman. 2020. Structural size measurements and isotopic signatures of foraging among adult male and female Adelie penguins (Pygoscelis adeliae) nesting along the Palmer Archipelago near Palmer Station, 2007-2009 ver 5. Environmental Data Initiative} \doi{10.6073/pasta/98b16d7d563f265cb52372c8ca99e60f}
+#' @source {Gentoo penguins: Palmer Station Antarctica LTER and K. Gorman. 2020. Structural size measurements and isotopic signatures of foraging among adult male and female Gentoo penguin (Pygoscelis papua) nesting along the Palmer Archipelago near Palmer Station, 2007-2009 ver 5. Environmental Data Initiative} \doi{10.6073/pasta/7fca67fb28d56ee2ffa3d9370ebda689}
+#' @source {Chinstrap penguins: Palmer Station Antarctica LTER and K. Gorman. 2020. Structural size measurements and isotopic signatures of foraging among adult male and female Chinstrap penguin (Pygoscelis antarcticus) nesting along the Palmer Archipelago near Palmer Station, 2007-2009 ver 6. Environmental Data Initiative} \doi{10.6073/pasta/c14dfcfada8ea13a17536e73eb6fbe9e}
+#' @source {Originally published in: Gorman KB, Williams TD, Fraser WR (2014) Ecological Sexual Dimorphism and Environmental Variability within a Community of Antarctic Penguins (Genus Pygoscelis). PLoS ONE 9(3): e90081. doi:10.1371/journal.pone.0090081}
+#' @details 
+#' Replicating this dataset:
+#' ```
+#' require("palmerpenguins")
+#' d <- palmerpenguins::penguins
+#' d <- d[!is.na(d$sex), ] ## Remove missing
+#' d <- d[, c(3:6, 1, 7, 2)] ## Numeric to front, group factors, remove year
+#' penguins <- as.data.frame(d) ## Remove {tibble} dependency
+#' ## save(penguins, file = "./data/penguins.rda")
+#' ```
+#' @examples
+#' library("spinifex")
+#' str(spinifex::penguins)
+#' dat <- scale_sd(spinifex::penguins[, 1:4])
+#' clas1 <- spinifex::penguins$species
+#' clas2 <- spinifex::penguins$sex
+#' 
+#' bas <- basis_pca(dat)
+#' mv <- manip_var_of(bas)
+#' mt <- manual_tour(bas, mv)
+#' 
+#' ggt <- ggtour(mt, dat, angle = .2) +
+#'   proto_default(list(color = clas1, shape = clas2))
+#' \dontrun{
+#' animate_plotly(ggt)}
+"penguins"
